package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````["````````!``````````-"Q````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````&NP`````````````````````````````&8````````````````````!
M``````````$````%````````````````````````````````````!)P`````
M```$G``````````0`````````0````8```!XJP```````'BK````````>*L`
M``````#8!``````````%`````````!`````````"````!@```)"K````````
MD*L```````"0JP```````"`"````````(`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```!8DP```````%B3````````6),```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````>*L```````!X
MJP```````'BK````````B`0```````"(!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`*D&(70M#8X0D:G&+E?XVQV2-C_@!````!`````!````1TY5```````$````
M#P`````````[````1P````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``HA'````2````$D```!+````````````````````3```````
M``!-````3P```%```````````````%$```!2````````````````````````
M`%,```!4````50````````!6````5P``````````````6`````````!9````
M````````````````6@```%L`````````70````````!>`````````%\`````
M``````````````````````````````!@````````````````````80``````
M``!B````````````````````9````!E^"H=_J9R;:@E#UC_/TFPA_^0.#3J7
M"W)0G]C#Y3\LB0=PT]EQ6!RM2^/`:QJ>4-5DU'R93\.;+\6;MC-BV^W_8?)A
M:W^:?+OCDGRS`8MO0OK7AT-%U>QGK\QF%8PES*/@^TG/WD<MXT?&`>"G`@IO
MQ=\?^Z%L8````````````````````````````````````````````P`,`$`?
M``````````````````#G`@``$0````````````````````````"E`@``$@``
M``````````````````````!]`0``$@````````````````````````"%````
M$@`````````````````````````,`@``$@````````````````````````",
M`@``$@````````````````````````#)`0``$@``````````````````````
M``"N````$@````````````````````````"%`@``$@``````````````````
M``````"D````$@````````````````````````!(`@``$@``````````````
M``````````#6`0``$@````````````````````````!]````$0``````````
M``````````````"5````$@````````````````````````"P`0``$@``````
M``````````````````#7`@``$@````````````````````````#\`0``$@``
M```````````````````````A`0``$@````````````````````````"A`0``
M$@````````````````````````#3````$@````````````````````````##
M````$@````````````````````````!8````$@``````````````````````
M```!````(``````````````````````````8`0``$@``````````````````
M``````"]`@``$@`````````````````````````=````(```````````````
M``````````".````$@````````````````````````#*````$@``````````
M``````````````"O`@``$@````````````````````````"3`0``$@``````
M``````````````````![````$0````````````````````````#9````%@``
M``````````````````````!;`0``$@````````````````````````#L````
M$@````````````````````````"$`0``$@````````````````````````!%
M`0``$@````````````````````````!;`@``$@``````````````````````
M``#"`0``$@`````````````````````````'`0``$@``````````````````
M``````#(`@``$@````````````````````````"U`0``$@``````````````
M```````````V`0``$@````````````````````````"J`@``$@``````````
M``````````````!O`0``$@````````````````````````#0`0``$@``````
M``````````````````"7`@``$@````````````````````````!V`0``$@``
M```````````````````````O`0``$@````````````````````````":`0``
M$0`````````````````````````M`@``$@````````````````````````"+
M`0``$@````````````````````````"-````$@``````````````````````
M``!)````(@`````````````````````````8`@``$@``````````````````
M``````!3`0``$@````````````````````````"]`0``$@``````````````
M``````````#@`@``$@````````````````````````!Y`@``$@``````````
M``````````````#G`0``$@````````````````````````"J`P``$@``````
M``````````````````!L`@``$0````````````````````````"U````$@``
M``````````````````````#\````$@`````````````````````````Y`@``
M$@`````````````````````````W````$@````````````````````````"<
M````$@````````````````````````!B`0``$@``````````````````````
M``!J````$@````````````````````````#U`0``$@``````````````````
M``````#V`P``$`#Q_P"X``````````````````"8`P``$@`,`.9%````````
M'`````````#:`P``$``5``"P``````````````````#G`P``$``5``"P````
M``````````````!K!```$@`,`*(]````````M`$```````#<`P``(``5``"P
M```````````````````3!```$``5`%"P```````````````````C!```$@`,
M`*(\````````-@````````!X!```$0`5`$BP````````"``````````K!```
M$``6`%"P``````````````````#+`P``$0`-`.!1````````!`````````".
M`P``$@`,``Q0````````N@$```````!(`P``$@`,`!A,````````X`$`````
M``""!```$@`,`'!$````````5``````````J`P``$@`,`)(]````````$```
M``````#@`P``$@`,`.P@````````(@````````"_`P``$``6`'BP````````
M``````````!$````$@`,`$`?````````K`$```````!`!```$``6`'BP````
M``````````````!>`P``$@`,`!9$````````6@`````````(!```$@`,``I/
M`````````@$```````!2!```$``5`%"P``````````````````""`P``$@`,
M`'X_````````\@`````````W!```$@`,`*Y.````````7`````````"*!```
M$@`,`'!`````````I@,```````!%!```$@`,`-1&````````1`4````````[
M`P``$@`,`%8_````````*`````````!L`P``$@`,`-@\````````N@``````
M``"S`P``$@`,`/A-````````M@````````!9!```$@`,``)&````````T@``
M````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`7U]L:6)C7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI
M>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9F%I;`!?7V5N=FER
M;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S<P!O<&5N9&ER`')E861D:7(V-`!S
M=')L96X`7U]S<')I;G1F7V-H:P!U;FQI;FL`8VQO<V5D:7(`<FUD:7(`4$Q?
M8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN84QO861E<@!097)L7VYE=UA3`%!E
M<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`4&5R;%]S=E]S971P=@!M96UC:'(`
M4&5R;%]S=E]S971P=FX`7U]M96UM;W9E7V-H:P!R96%L;&]C`&=E='!I9`!?
M7VUE;6-P>5]C:&L`<W1R8VAR`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C
M:'(`;65M8W!Y`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`
M<F5A9`!M96UC;7``9V5T=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F
M<')I;G1F7V-H:P!O<&5N-C0`4&5R;%]G=E]F971C:'!V`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;6=?<V5T`%!E<FQ?<WES7VEN
M:70S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7V%T9F]R:U]L;V-K`%!,7V1O
M7W5N9'5M<`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]P87)S90!P97)L7V1E
M<W1R=6-T`'!E<FQ?9G)E90!097)L7W-Y<U]T97)M`'!E<FQ?86QL;V,`<&5R
M;%]C;VYS=')U8W0`<&5R;%]R=6X`;65M<V5T`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\`;&EB8RYS;RXV`&QD+6QI;G5X+7)I<V-V-C0M;'`V-&0N
M<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`%]?0E-37T5.1%]?`%])3U]S=&1I;E]U<V5D
M`%]?9&%T85]S=&%R=`!?7T1!5$%?0D5'24Y?7P!?7V=L;V)A;%]P;VEN=&5R
M)`!S:&%?=7!D871E`%]?4T1!5$%?0D5'24Y?7P!X<U]I;FET`%]?8G-S7W-T
M87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]D:64`<&%R
M7VEN:71?96YV`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(W`"]U
M<W(O;&EB+W!E<FPU+S4N-#`O8V]R95]P97)L+T-/4D4````````"``$``P`#
M``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#``,``P`#``$``P`!``$`
M!``#``$``P`#``$``P`!``,``P`!``,``0`!``,``0`#``,``P`!``,``P`#
M``$``P`$``,``0`#``,``P`!``,``P`!``,``0`!``4``P`#``,``P`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0````$``P`$`P``$````$````"TD98&```%`)<$```0````
MLY&6!@``!`"B!```$````(>1E@8```,`K00````````!``$`#@,``!``````
M````AY&6!@```@"M!````````'BK`````````P`````````.(0```````("K
M`````````P````````#.(0```````(BK`````````P````````"0(0``````
M`*"O`````````P`````````83````````/"O`````````P````````!(L```
M`````/BO`````````P````````!`'P````````"P`````````P``````````
ML````````!BP`````````P````````!`4P```````""P`````````P``````
M```8DP```````"BP`````````P`````````@DP```````#"P`````````P``
M```````HDP```````#BP`````````P`````````PDP```````$BP````````
M`P````````"H50```````)"O`````````@````(``````````````)BO````
M`````@````P``````````````*BO`````````@````X``````````````+"O
M`````````@```!@``````````````+BO`````````@```!L`````````````
M`,"O````````"P```"$``````````````,BO`````````@```",`````````
M`````-"O`````````@```"8``````````````-BO`````````@```#(`````
M`````````."O`````````@```#8``````````````.BO`````````@```#X`
M`````````````,"M````````!0````,``````````````,BM````````!0``
M``0``````````````-"M````````!0````4``````````````-BM````````
M!0````8``````````````."M````````!0````<``````````````.BM````
M````!0````@``````````````/"M````````!0````D``````````````/BM
M````````!0````H```````````````"N````````!0````L`````````````
M``BN````````!0````T``````````````!"N````````!0````\`````````
M`````!BN````````!0```!```````````````""N````````!0```!$`````
M`````````"BN````````!0```!(``````````````#"N````````!0```!,`
M`````````````#BN````````!0```!0``````````````$"N````````!0``
M`!4``````````````$BN````````!0```!8``````````````%"N````````
M!0```!<``````````````%BN````````!0```!D``````````````&"N````
M````!0```!H``````````````&BN````````!0```!P``````````````'"N
M````````!0```!T``````````````'BN````````!0```!X`````````````
M`("N````````!0```!\``````````````(BN````````!0```"(`````````
M`````)"N````````!0```"0``````````````)BN````````!0```"4`````
M`````````*"N````````!0```"<``````````````*BN````````!0```"@`
M`````````````+"N````````!0```"D``````````````+BN````````!0``
M`"H``````````````,"N````````!0```"L``````````````,BN````````
M!0```"P``````````````-"N````````!0```"T``````````````-BN````
M````!0```"X``````````````."N````````!0```"\``````````````.BN
M````````!0```#```````````````/"N````````!0```#$`````````````
M`/BN````````!0```#,```````````````"O````````!0```#0`````````
M``````BO````````!0```#4``````````````!"O````````!0```#<`````
M`````````!BO````````!0```#@``````````````""O````````!0```#D`
M`````````````"BO````````!0```#H``````````````#"O````````!0``
M`#L``````````````#BO````````!0```#P``````````````$"O````````
M!0```#T``````````````$BO````````!0```#\``````````````%"O````
M````!0```$```````````````%BO````````!0```$$``````````````&"O
M````````!0```$(``````````````&BO````````!0```$,`````````````
M`'"O````````!0```$0``````````````'BO````````!0```$4`````````
M`````("O````````!0```$8`````````````````````````EY,``#,#PT$#
MO@,B$P-#_9."`R(34Q,`@[*"`&<`#@`7G@```SX.(6<##@`3````%YX```,^
MCB!G`PX`$P```!>>```#/@X@9P,.`!,````7G@```SZ.'V<##@`3````%YX`
M``,^#A]G`PX`$P```!>>```#/HX>9P,.`!,````7G@```SX.'F<##@`3````
M%YX```,^CAUG`PX`$P```!>>```#/@X=9P,.`!,````7G@```SZ.'&<##@`3
M````%YX```,^#AQG`PX`$P```!>>```#/HX;9P,.`!,````7G@```SX.&V<#
M#@`3````%YX```,^CAIG`PX`$P```!>>```#/@X:9P,.`!,````7G@```SZ.
M&6<##@`3````%YX```,^#AEG`PX`$P```!>>```#/HX89P,.`!,````7G@``
M`SX.&&<##@`3````%YX```,^CA=G`PX`$P```!>>```#/@X79P,.`!,````7
MG@```SZ.%F<##@`3````%YX```,^#A9G`PX`$P```!>>```#/HX59P,.`!,`
M```7G@```SX.%6<##@`3````%YX```,^CA1G`PX`$P```!>>```#/@X49P,.
M`!,````7G@```SZ.$V<##@`3````%YX```,^#A-G`PX`$P```!>>```#/HX2
M9P,.`!,````7G@```SX.$F<##@`3````%YX```,^CA%G`PX`$P```!>>```#
M/@X19P,.`!,````7G@```SZ.$&<##@`3````%YX```,^#A!G`PX`$P```!>>
M```#/HX/9P,.`!,````7G@```SX.#V<##@`3````%YX```,^C@YG`PX`$P``
M`!>>```#/@X.9P,.`!,````7G@```SZ.#6<##@`3````%YX```,^#@UG`PX`
M$P```!>>```#/HX,9P,.`!,````7G@```SX.#&<##@`3````%YX```,^C@MG
M`PX`$P```!>>```#/@X+9P,.`!,````7G@```SZ."F<##@`3````%YX```,^
M#@IG`PX`$P```!>>```#/HX)9P,.`!,````7G@```SX."6<##@`3````%YX`
M``,^C@AG`PX`$P```!>>```#/@X(9P,.`!,````7G@```SZ.!V<##@`3````
M%YX```,^#@=G`PX`$P```!>>```#/HX&9P,.`!,````7G@```SX.!F<##@`3
M````%YX```,^C@5G`PX`$P```!>>```#/@X%9P,.`!,````=<8;LHNC*X(`0
MIN1._%+XJH<7F0```SGI`R,XM/HC-,3ZDP4$^Q,&A/H3!<3[(R[T^H,W"0`C
M-/3\@4?O\%_V%Y8```,VA@&RA1>5```#-64$[S!`(Y>7``"#MR<%@\<'`&.%
M!PZ7EP``@[>G`9>4``"3A*0*DI>88X,IQ/N#1Z=+&X5)``X%D^<W`",-]TKO
M\!_L@S4$^Y>7``"#MX<!D&,#N`4`@R?$^ZJ&%S<``!,'1UL7-0``$P5%6ICN
ME.0CL`8!B.:0Z@5'C2EC6?<,H04;A3<`$4>089,7-P"VEP4GD..A!>,9I_X.
M!XAL-I<C,`<`3H8!1Y<E``"3A866[_`?NS7)B&P3"D3\[_!?VJJ)TH47-0``
M$P7%)^\0('`EP8AL[_#?M._PG\L#-X3\@S<)`+F/`4>EZ^9@1F2F9`9I0GI.
MA>)Y)6&"@._P7\:7E```DX2$_(CL(<7O\%_/EY<``(.W!_*%9C.'1P`88S:7
M(PL'D@&WB&SO\'^[8;>(:`'%[R!04VF_TH47-0``$P7%&.\0H&B(Z$'5Y;<1
M1ZFW!47O\-^W[_"?X^\`(`*JAQ>5```#-67P@F4P`!-Q`?^!1@%'"HCO\)_>
M`I"7D0``DX$A;X*```!!$2+@!N0`"!>5```3!>7REY<``).'9_)CBZ<`EY<`
M`(.WI^>)QP)DHF!!`8*'HF`"9$$!@H`7E0``$P4%\)>5``"3A87OB8U!$9/7
M-4#]D2+@!N0`"+Z5A861R9>7``"#MR?DB<<"9*)@00&"AZ)@`F1!`8*`EY<`
M`(/'!^R5ZT$1(N`&Y``(EY<``(.WY^.1QQ>5```#-47E@I?O\%_VHF`"9(5'
M%Y<``",(]^A!`8*`@H!!$2+@!N0`"`)DHF!!`96_$P$!U",X@2J`!2,\$2HC
M-)$J(S`A*R,\,2F7DP``@[.#V9,&A-3!;I,(A0.3#X4'@[<#`",T]/R!1S:(
MDXX.\#</_P`#M@@`H0A!")-5!@(3%X8!$Y.%`9,2A@"35X8"`A<37H8`DU2&
M`P&3`A.S\N(!L_?7`1-3`P(S9U<`,W[>`:(%Q8\S9\<!&U:&`;/UY0&SYV<`
M48_-CR,XZ/XC//C^XY'X^P,_!-N#/H3;`S<$W`,^A-4#,P36@SB$U@,X!->#
M-837@S\$V).$!B`1H+*/L&*<8KJ"H0:QC[/'YP&SQ\<!$Y<7`/V#78\"%P&3
MN/X:CG:/1H.6CL*(+HC^A>.8U/P080QI@SB%``,XA0&#-H34`S,%`I-7M@$3
M%U8`-XZ"6A,.GIE=C_*6L\<%`1/?*``"%Y.>Z`&:EK/N[@$!D[/W%P$VE[/'
M!P&#-@35$Y\.`A-?#P(^EP(7L\?E`0&3\8_REI-2MP&3'U<`K8_"EK/O7P"V
MEY-2)@#^EY,6Y@&#/X35L^96`+/.W@""%X&3L_[N`/*?D]2W`:Z?DY)7`+/.
M[@&SXI(`_IZ6GI,?YP&#,@36"8,SY^\`@AZ3GP8"N8Z3W@X"D]\/`O*2_8X6
MGY/4O@&3DEX`L\;V`?J6,^^2`/J6DY+G`0,_A-:)@[/G\@""%I,2!P(]CX&2
MD]("`G*?,W?7`7Z?D]2V`9.?5@`S1U<`>I<S[Y\`>I>#/P37$Y_N`9/>+@`S
M;]\!$YD'`@(7L\?G`0&3$UD)`K..SP'UCY:>DQ]7`)-2MP&SQR<!]I>S[E\`
M]I>#,H37D]XF`).?Y@&S[]\!LT;_`9,4#P*"%X&3@9"SCL(!^8[*GA.?5P"3
MTK<!I8[VEK-N7P#VEH,R!-B37B<`$Q_G`3-OWP$SQ^\!$YD/`H(6@9(360D"
MLX["`7V/IIZ3GU8`D]*V`3-')P%VE[/N7P!VEX,_A-B3WB<`DY+G`;/BT@&S
M1U\`DQ0/`@(7`9.!D+..SP'UC\J>$Q]7`)-?MP&EC_:7LV[_`?:7`S\$V9/>
M)@"3G^8!L^_?`;/&\@$3F0("@A>!DQ-9"0*S#L\!^8ZFGA.?5P"3TK<!L\8F
M`?:6LVY?`/:6@S*$V9->)P`3'^<!,V_?`3/'[P&3E`\"@A:!DH&0LX["`7V/
MRIZ3GU8`D]*V`26/=I>S[E\`=I>#,@3:D]XG`).?YP&S[]\!LT?_`1,9#P("
M%P&3$UD)`K..P@'UCZ:>$Q]7`)-2MP&SQR<!]I>S;E\`]I>#,H3:D]XF`!.?
MY@$S;]\!L\;O`9.4#P*"%X&3@9"SCL(!^8[*GI.?5P"3TK<!I8[VEK/N7P#V
MEH,R!-N37B<`DQ_G`;/OWP$S1_\!$QD/`H(6@9(360D"LX["`7V/IIX3GU8`
MD]*V`3-')P%VE[-N7P!VEX,RA-N3WB<`$Y_G`3-OWP&SQ^\!DY0/`@(7`9.!
MD+..P@'UC\J>DQ]7`)-2MP&EC_:7L^Y?`/:7@S($W)/>)@"3G^8!L^_?`;-&
M_P&3&0\"@A>!DY/9"0*SCL(!^8ZFGA.?5P"3TK<!L\8V`?:6LVY?`(,TA-SV
MEI,2YP&37B<`L^+2`3/'7P`3GP8"$YD/`A-?#P(360D"LX;$`7V/SI:3'E\`
MDU^_`3-')P$VE[/F_@&#-`3=-I>3WR<`DY;G`;/F]@&SQ](`DQX'`I.?`@*3
MW@X",X?$`9/?#P*S]^<!2I>3DEX`D]2^`;/']P&ZES/GD@"ZEX,TA-T3%^\!
M@A<37R\`@9,S9^<!$]FW`9.2!@(3GU<`N8[RE)/2`@(S;R\!L_;6`::?L\96
M``(?$U\/`OZ6^I8#.03>DY_N`1.?!@*3WBX`$U\/`K/NWP&3%%\`<IF3'P<"
M$UZ_`3-'UP&3WP\",^[$`7V/RI(S1_<!`AX37@X"%I>3DN<!B8-RE[/B\@"S
MQUX``SF$WI,4!P*!D+6/M_;9;I.&%KJ3V;0!$YY4`#:9,VX^`8(7RI^!DP(>
M_I<37@X"/IZ3'^\!$U\O`+/O[P&#-P3?$QD.`A-9"0(SS_(!DUFY`3-/[P""
M'A,760"3W@X",V<W`;:7`A\37P\"]I<"%_J7`9,^EY.>Y`&)@+/NG@"#-X3?
MDQD'`I/9"0(SS]\!D]2Y`3-/SP&"$A.>60"3T@(",VZ>`+:7`A\37P\"EI<"
M'OJ7$UX.`CZ>$Q_I`1-9*0`S;R\!@S<$X),2#@*3T@("L\3N`1/9L@&YC((?
M$Y=2`)/?#P(S9R<!MI>"%(&0_I<"%Z:7`9,^EY.?Z0&3V2D`L^\_`8,WA."3
M%`<"@9`S2?\!D]FT`3-)R0&"'A.>5`"3W@X",VX^`;:7`AD360D"]I<"'LJ7
M$UX.`CZ>DY[B`9/2(@"S[EX`@S<$X1,9#@(360D"L\+?`9-9N0&SPN(``A\3
M%UD`$U\/`C-G-P&VEX(2D]("`OJ7`A>6EP&3/I<3G^0!B8`S;Y\`@S>$X9,2
M!P*3T@("L\3N`9/9L@&SQ,0!@A\3GE(`D]\/`C-N/@&VEX(4@9#^EP(>II<3
M7@X"/IZ3'^D!$UDI`(,W!.*S[R\!DQ0.`H&0,TG_`9/9M`$S2>D`@AX3EU0`
MD]X.`C-G-P&VEP(9$UD)`O:7`A?*EP&3/I>3GN(!D](B`+/N7@"#-X3B$QD'
M`A-9"0*SPM\!DUFY`;/"P@$"'Q,>60`37P\",VX^`;:7@A*3T@("^I<"'I:7
M$UX.`CZ>$Y_D`8F`,V^?`(,W!..3$@X"D]("`K/$[@&3V;(!N8R"'Q.74@"3
MWP\",V<W`;:7@A2!D/Z7`A>FEP&3/I>3'^D!$UDI`+/O+P&#-X3CDQ0'`H&0
M,TG_`9/9M`$S2<D!@AX3GE0`D]X.`C-N/@&VEP(9$UD)`O:7`A[*EQ->#@(^
MGI.>X@&3TB(`L^Y>`(,W!.03&0X"$UD)`K/"WP&36;D!L\+B``(?$Q=9`!-?
M#P(S9S<!MI>"$I/2`@+ZEP(7EI<!DSZ7$Y_D`8F`,V^?`(,WA.23$@<"D]("
M`K/$[@&3V;(!L\3$`8(?$YY2`)/?#P(S;CX!MI>"%(&0_I<"'J:7$UX.`CZ>
MDQ_I`1-9*0"S[R\!@S<$Y9,4#@*!D#-)_P&3V;0!,TGI`((>$Y=4`)/>#@(S
M9S<!MI<"&1-9"0+VEP(7RI<!DSZ7DY[B`9/2(@"S[EX`@S>$Y1,9!P(360D"
ML\+?`9-9N0&SPL(!`A\3'ED`$U\/`C-N/@&VEX(2D]("`OJ7`AZ6EQ->#@(^
MGA.?Y`&)@#-OGP"#-P3FDQD.`I/9"0*SPNX!D]2Y`;/"X@""'Q.760"3WP\"
M18^VEX(2D]("`OZ7`A>6EP&3/I>3'^D!$UDI`+/O+P&#-X3FDQ0'`H&0LT+_
M`1/9M`&SPL(!@AX3GE0`D]X.`C-N+@&VEX(2D]("`O:7`AZ6EQ->#@*SCL<!
MDY+I`9/9*0"SXC(!@S<$YQ.9#@(360D",\Y?`)-9N0$S3NX``A\3%UD`$U\/
M`C-G-P&VEP(>$UX.`OJ7`A<!DQ.?Y`'REXF`,V^?`#..YP`#-X3GL\?B`;/'
MUP&3%`X"@A^!D)/?#P(VEX(7DYY4`)/9M`&!DWZ7/I>3'^D!L^<^`1-9*0"S
M[R\!/I>#-P3H,TG_`9,>!P(S3LD!@A*3W@X"D]("`K:7`AX37@X"EI>3EEX`
MD]*^`;/F5@`3E^0!\I>)@(,RA.A%C[:7M_;&(Y,4!P(3G@<"DY<F`).'Q\V!
MD+/F[P`3&0\"$UX.`C./\@`360D"L_*?`+/VU@%*G[/F5@`36;X!DQ)>`/J6
M,^\B`?J6`SD$Z1.?[@&3WBX`,V_?`9.2#P(S9^<!DY\&`I/?#P*S=I\`LP[Y
M`)/2`@(S=\<!EIX3V;\!DY)?`%6/=I>3%NX!L^XB`1->+@"SYL8!=I>#/H3I
MDY(&`I/2`@(S;M\``A<!DS-Y7P"^GC-^_@&FGC-N+@&3%%<`$UFW`7:>L^XD
M`7:>`SD$ZI.>[P&3WR\`L^[^`9,4#@*SYM8!`A^!D+/_7@`S#OD`$U\/`OF.
M>IZSYO8!D]FT`9.?5``3&><!$U\G`#.'Q@&S9ND!,^X_`0,_A.IREY.?!@*3
MWP\",^[>``(7`9,S^?X!/I\S?IX`%I\S;BX!DQ)7`!-9MP%ZGC/O(@%ZG@,Y
M!.L3G^0!B8`S;Y\`DQ(.`K/FY@&"'I/2`@*S=/\!,P[Y`)/>#@+YCG:>Q8Z3
MV;(!DY12`!,9YP&37B<`,X?&`;-FV0$S[C0!@SZ$ZW*7DY0&`H&0,V[?``(7
M`9,S>9\`OIXS?EX`_IXS;BX!DQ]7`!-9MP%VGK/N+P%VG@,Y!.R3GN(!D](B
M`+/N7@"3'PX"L^;6`0(?D]\/`K/RG@`S#OD`$U\/`OF.>IZSYE8`D]F_`9.2
M7P`3&><!$U\G`#.'Q@&S9ND!,^XR`0,_A.QREY.2!@*3T@(",^[>``(7`9,S
M^5X`/I\S?OX!)I\S;BX!DQ17`!-9MP%ZGC/O)`%ZG@,Y!.T3G^\!D]\O`#-O
M_P&3%`X"L^;F`8(>@9"S?U\`,P[Y`)/>#@+YCG:>L^;V`9/9M`&3GU0`$QGG
M`9->)P`SA\8!LV;9`3/N/P&#/H3M<I>3GP8"D]\/`C-NWP`"%P&3,WG_`;Z>
M,WZ>`):>,VXN`9,25P`36;<!=IZS[B(!=IX#.03NDY[D`8F`L^Z>`),2#@*S
MYM8!`A^3T@("L_3^`3,.^0`37P\"^8YZGL6.D]FR`9.44@`3&><!$U\G`#.'
MQ@$S[C0!LV;I`8,TA.YREQ.?!@(37P\",^[>``(7`9,S^>X!OI0S?EX`II\S
M;BX!DQ17`!-9MP%^GK/O)`%^G@,Y!.^3G^(!D](B`+/O7P"3%`X"L^;V`8(>
M@9"S\N\!,P[Y`)/>#@+YCG:>L^96`)/9M`&3DE0`$QGG`9->)P`SA\8!,^XR
M`;-FV0&#,H3O<I>3G@8"D]X.`C/NWP`"%P&3,_G?`;Z2,WZ>`!:?,VXN`9,2
M5P`36;<!>IXS[R(!>IX#.03P$Y_D`8F`,V^?`),2#@*SYN8!@A^3T@("LW3?
M`3,.^0"3WP\"^8Y^GA/9L@&3GU(`Q8Z3%.<!"8-%C_*6@S2$\#/N+P'REI,?
M!P*3WP\",V[O`((6@9(S>?\!OI0S?EX`IIXS;BX!DY16`!/9M@%VGK/N)`%V
MGH,T!/$3F>(!D](B`),>#@(S;ED`,V?'`0(?D]X.`K."]`!UC[-T_@$37P\"
M%I]%CY.27@"3U+X!>I<S[Y(``SF$\7J7$Y_F`8F"LV;?``(7`9.3D@8"D]("
M`C-OW@"36;<!/IF3%%<`RI^SY#0!,WE>`#-_WP$S;R\!@A2!D'Z?`SD$\B:?
MDQ\/`I/?#P*3E.X!D]XN`+/NU`$^F9.47P"3U[\!L^;6`=V,`AZS]^8`$UX.
M`I.6!`*S]%X`2I[%C_*7@9*^EI,4YP$)@]F,@SF$\A.9!@*WMY@R$UD)`C/'
MG@"*!Y.'9QTS1^<!$QY9`!-?N0$S;NX!`A<SC_D`%I\!DP(>>I<37@X".IX3
MG^\!$]<O`+-O[P"3$@X"`S\$\Y/2`@(SQ_0!D]FR`36/@AZ3EE(`/I^SYC8!
MD]X.`@(7^IX!DX(6=I>!DKJ6DQ[I`1-7*0"S[NX`$YD&`@,WA/,360D",\_?
M`9-9N0$S3\\!@A03'ED`@9`S;CX!/I<"'Q-?#P(FEP(>>I<37@X".IX3G^(!
MD](B`#-O7P"3%`X"`S<$](&0L\+N`9/9M`&SPM(`@A^3EE0`D]\/`K/F-@$^
MEX(2D]("`GZ7@A86EX&2NI:3'^D!$UDI`+/O+P&3D@8"`S>$])/2`@(S2?\!
MD]FR`3-)R0&"'A.>4@"3W@X",VX^`3Z7`AD360D"=I<"'DJ7$UX.`CJ>DY[D
M`8F`L^Z>`!,9#@(#-P3U$UD)`K/$WP&36;D!M8P"'Y,660`37P\"L^8V`3Z7
M@A2!D'J7@A8FEX&2NI83G^(!D](B`#-O7P"3E`8"`S>$]8&0L\+N`9/9M`&S
MPL(!@A\3GE0`D]\/`C-N/@$^EX(2D]("`GZ7`AX6EQ->#@(ZGI,?Z0$362D`
ML^\O`9,2#@(#-P3VD]("`C-)_P&3V;(!,TG9`((>DY92`)/>#@*SYC8!/I<"
M&1-9"0)VEX(62I>!DKJ6DY[D`8F`L^Z>`!.9!@(#-X3V$UD)`K/$WP&36;D!
ML\3$`0(?$QY9`!-?#P(S;CX!/I>"%(&0>I<"'B:7$UX.`CJ>$Y_B`9/2(@`S
M;U\`DQ0.`@,W!/>!D+/"[@&3V;0!L\+2`((?DY94`)/?#P*SYC8!/I>"$I/2
M`@)^EX(6%I>!DKJ6DQ_I`1-9*0"S[R\!DY(&`@,WA/>3T@(",TG_`9/9L@$S
M2<D!@AX3GE(`D]X.`C-N/@$^EP(9$UD)`G:7`AY*EQ->#@(ZGI.>Y`&)@+/N
MG@`3&0X"`S<$^!-9"0*SQ-\!DUFY`;6,`A^3%ED`$U\/`K/F-@$^EX(4@9!Z
MEX(6)I>!DKJ6$Y_B`9/2(@`S;U\`DY0&`@,WA/B!D+/"[@&3V;0!L\+"`8(?
M$YY4`)/?#P(S;CX!/I>"$I/2`@)^EP(>%I<37@X".IZ3'^D!$UDI`+/O+P&3
M$@X"`S<$^9/2`@(S2?\!D]FR`3-)V0""'I.64@"3W@X"L^8V`3Z7`AD360D"
M=I>"%DJ7@9*ZEI.>Y`&)@+/NG@`3F08"`S>$^1-9"0*SQ-\!DUFY`;/$Q`$"
M'Q,>60`37P\",VX^`3Z7@A2!D'J7`AXFEQ->#@(ZGA.?X@&3TB(`,V]?`),4
M#@(#-P3Z@9"SPNX!D]FT`;/"T@""'Y.65`"3WP\"L^8V`3Z7@A*3T@("?I>"
M%A:7@9*ZEI,?Z0$362D`L^\O`9.9!@(#-X3ZD]D)`K-"_P$3V;D!L\+"`8(>
M$YY9`)/>#@(S;BX!/I>"$I/2`@)VEP(>%I<37@X"LP['`9.2Y`&)@+/BD@`3
MF0X"`S<$^Q-9"0(SSE\`DU2Y`3-.W@`"'Y,660`37P\"Q8X^EP(>$UX.`GJ7
M@A:!DA.?Z0%REY/9*0`S;S\!,P[7`(,VA/LSQ^(!,T?7`8(?D]\/`I,4#@*^
ME@(7@9`!D_Z6D]FT`9.?5`"ZEI,>Z0$#-P3\$UDI`+/O/P&S[BX!_I:S3]\!
MNI>"$H(6,\[/`8&2LI>3T@("`AX3U[8!$Y96`!->#@*6EUF.\I<3E^0!B8"R
MET6/+I<S!F\`QI;"GH(7@9,"%H(6DY4.`@(7@9(!DH&1`9,<X13E$/$,[8,V
MA/R#MP,`M8^!1ACID>^#,($K`S0!*X,T@2H#.0$J@SF!*1,!`2R"@._@;_Q=
M<:+@AN0F_%[D@`B7AP``@[?G@X.[!P!CA`L(3O12\%;L@T<%`"J*KHJJB1,'
MT`.UQV.&YP"#QQD`A0G]^[N)24&#M`L`N<Q*^%KH7HD3"]`#3H;2A2:%[^"O
MP;.'-`$)Y8/'!P!C@F<#@S2)`"$)[?!">:)Y`GKB:D)KIF`&9*)K)H7B=&%A
M@H`S"7E!$UDY0(4)(Z`J`<Z4X;^!256W@43IOZ)Y`GKB:LF_<7$B\2;M2ND`
M&0;U%WD```,YJ7>3!83U@S<)`",\]/R!1ZJ$[^`OX17A@R>$]KUF$6?UCV.%
MYP`I9V.:YP`FA8E%[^!/P!,U%0`1H`%%`S>$_8,W"0"YCP%'F>>J<`ITZF1*
M:4UA@H#OX._J57&BX4[UAN6`"9=Y``"#N0EQ@[<)`",\]/J!1QG%)OV#1P4`
MJH29[^IT`S>$^X.W"0"YCP%'8Y$'#JY@#F2J>6EA@H!*^>_@3^0JB6,,!0Q2
M\4J%[^!OMEG-@T8U`1,*-0&;AB;]&X8&`)GB`T8:`&W2`T<U`1L')_V;!@<`
M`>N#1QH`FX<G_9N&!P"]S_'2)H56[>_@;["JBE*%[^#OK[N*J@")*E:%[^`O
ML-*'5H8FAY<F``"3A@:,B44JBN_@S]B3!83S4H7OX"^\_5=C"?4`@R>$]+UF
M$6?UCV.*YP)2A>_@C[92A>_@+\9*A>IJ[^"OK#WQ2H7OX"^Z)H7OX,^SZG1*
M>0IZ#;>#1BH`0;=2A>_P_^[!OR;]2OE2\5;M[^"OV.IT2GD)MP$1)N27=```
M@[3$82+H!NP`$+.'1`"(8Y=F``"3AH:8%W8```,VAF"7)0``DX6%@N_@#]"2
ME$)DB&#B8*)D%R<``!,')[NZAH%'%W8```,V9EN7)0``DX7E@05A;^!/N%UQ
MHN`F_$KX3O12\%;L@`B&Y/UR_7>3AX?[%I&%9)=Z``"#NBI7JHDNBA.&]/^S
M!?0`%Q4``!,%97^#MPH`(SST^H%'[^#/J1L)!0!C6R`!LP240)L'^?^^E`/'
MA/L=[XWOEW<``(.WYU52ALZ%DI>(8^_@[Z$#-X3[@[<*`+F/`4>IYX5B%I&F
M8`9DXG1">:)Y`GKB:F%A@H`^B?UWDX>'^[,$]``FA4J&DP7P`N_@+[9%V9=W
M``"#M\=0RH8FAI*7B&/.A>_@KZYUM^_@3\59<:+PINS*Z,[DAO32X%;\7O1B
M\(`8EWD``(.YJ4H#QP4`@[<)`",\]/B!1Y,'T`.NA"J)8Q3W`).$%0`FA>_@
M+Y"JBI,%1/E*A>_P7\0JBFG-[^#OCF-Y50N#*T3Y%WP```,\K$>."P-'"0#*
MAY,&T`-C`@<48P;7``/'%P"%!WW[NX<G00,Z#``3A2H`/I5>FN_@[XLC,*H`
M*<6#-PP``T<)`!,%&0#>EY1C$P;0`R.`Y@`!ZX6H`T<%``4%HX#G`#7#MH>%
M!N,8Q_X3!]`#(X#G`(4'`\<$`(4$A0>CC^?^=?L#-X3Y@[<)`+F/`4?AZZ9P
M!G3F9$9IIFD&:N)ZHGL"?&5A@H"#QP0`A00%"J,/^O[AVX/'!`"%!`4*HP_Z
M_OWSP;>VAU6W6OAF[&KH%WP```,\C#H#/0P`@S<-`*W/ZH<!2IAGH0?2A@4J
M9?^-)A.;-@"7=P``@Z<G0Q=W```3!Z="C>^%1UJ%',/OT#_^JHPYR9,;.@#:
MANJ%7H;OX`^1(S"<`9L'&@".![Z<([`,`$)[XFQ";2,J1/GIM=J%:H7OX,^>
M(S"L`*J,$<V3&SH`T;^!1_FU04L!2F&_6OAF[&KH[^"OJ$)[XFQ";1&_EW<`
M`(.WYS%!$2+@!N0`")*7`F2B8(ACEU8``).&9F@7=@```S9F,)<5``"3A652
M00%OX,^?'7&&[*+HIN2`$,K@3OQ2^%;T^7(7>@```SI**A:1@S<*`",\]/J!
M1^_@#X3]=Y.'!_NS!/0`!68JAP4&)H67%P``DX<G4I<6``"3AB92B47OX(^9
M^7>3AX?Z,PGT`":%RH4%9N_07_J;!`4`@4ECP00"FXH4`%:%[]`?[:J)"<DF
MAM:&RH7.E._@#YLC@`0``S>$^X,W"@"YCP%'B>^)8A:1YF!.A49DIF0&:>)Y
M0GJB>B5A@H#OX"^901$BX`;D``@"9*)@00$EOU%QHO&F[<KISN5>]8`9AO72
MX5;]6OEB\6;M_7+]=Y.'1_$6D9=[``"#NZL<JHFNA!<5```3!65(LP7T`(.W
M"P`C//3X@4?O\'^7*HF3!?`"3H7OT-_](<$7%0``$P7E1LZ%[_#?S$Z%`S>$
M^8.W"P"YCP%'8YX'$H5B%I&N<`YT[F1.::YI#FKJ>DI[JGL*?.IL;6&"@":%
M[]!__)<5``"3A:5#[]"_UZJ$7=7]=Q.'A_F3AX?Q!6NS"O0`DP<$^C.,9T&#
MQP0`,PKD`,7#8P<)`*:%2H7OT)_M)<TFA>_0']F3!_7_II>JC),&\`)CZ/0`
M,:@C@`<`_1=CAO0``\<'`.,)U_XFA>_0?]:JC$Z%[]#_U6:5!07C<&7UB44F
MATZ(EQ<``).'QSN7%@``DX;&.P5F4H7OT)_^UH52A>_0'^(!Z8,GC/B]9B%G
M]8]C@><$EQ4``).%13@!1>_0/\RJA.,+!>Z#QP0`M?-C#`D`@T<)`)N')_T;
MAP<`F>,#1QD`8=N%3)<4``"3A(0R0;>%15*%[]"_T4W]TH47%0``$P6E,N_P
MO[A2A>_07^MMO>_0__P!$2+H)N0&[``0DP7P`JJ$[]"_[!G!DP05`$)DXF`F
MA:)D!6%OT'_H.7$B^$[L!OPF]$KP@`#]<I=Y``"#N2D`%I&#MPD`(S3T_(%'
M6<F#1P4`*HG9Q^_07\83!A4`A6>JA&/HQPK]=Y.'A_PS!_0`RH4ZA>_0?]:3
MA_3_JI>3!O`"8VCU`!&H(X`'`/T78X:G``/'!P#C"=?^_7>3AX?\LP3T`":%
MDP7P`N_0'^,5R6/NI`3]=Y.'A_PS!?0`[]#?W@,WA/R#MPD`N8\!1Z'GA6(6
MD>)P0G2B=`)YXFDA88*``S>$_(.W"0"YCP%'A>>%8A:1XG!"=*)T`GGB:1<5
M```3!<4?(6%OT#_:(P`%`%6W`45]M^_07^LY<2+X)O1*\$[L@``&_!=Y```#
M.2GQDP1$_(,W"0`C-/3\@4>7>0``@[E)\::%%Q4``!,%)1_O\(_K%<4#)T3\
M@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%Q4``!,%A1SO\._H8?V7>0``@[DI
M[::%%Q4``!,%!1SO\&_G%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%
M%Q4``!,%91GO\,_D8?V7>0``@[D)Z::%%Q4``!,%91CO\$_C%<4#)T3\@[<)
M``X'NI>89YCC9=.8:Z$'F.-M_Z:%%Q4``!,%Q17O\*_@8?V7>0``@[GIY*:%
M%Q4``!,%117O\"_?%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%Q4`
M`!,%I1+O\(_<8?V7>0``@[G)X*:%%Q4``!,%I1'O\`_;%<4#)T3\@[<)``X'
MNI>89YCC9=.8:Z$'F.-M_Z:%%Q4``!,%!0_O\&_88?V7>0``@[FIW*:%%Q4`
M`!,%A0[O\._6%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%Q4``!,%
MY0OO\$_48?V7>0``@[F)V*:%%Q4``!,%Y0+O\,_2%<4#)T3\@[<)``X'NI>8
M9YCC9=.8:Z$'F.-M_Z:%%Q4``!,%10#O\"_08?V7>0``@[EIU*:%%Q4``!,%
M10?O\*_.%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%Q4``!,%I03O
M\`_,8?V7>0``@[E)T*:%%Q4``!,%)03O\(_*%<4#)T3\@[<)``X'NI>89YCC
M9=.8:Z$'F.-M_Z:%%Q4``!,%A0'O\._'8?V7>0``@[DIS*:%%Q4``!,%!0'O
M\&_&%<4#)T3\@[<)``X'NI>89YCC9=.8:Z$'F.-M_Z:%%Q4``!,%9?[O\,_#
M8?V7>0``@[D)R*:%%Q4``!,%9?/O\$_"%<4#)T3\@[<)``X'NI>89YCC9=.8
M:Z$'F.-M_Z:%%Q4``!,%Q?#O\*^_8?VFA1<5```3!47Z[_"OOJJ%&<47%0``
M$P5%]^_PS_2FA1<5```3!>7Y[_#/O*J%&<47%0``$P5E^N_P[_*FA1<5```3
M!87Z[_#ONJJ%%<T7%0``$P4%ZN_P#_$#-X3\@S<)`+F/`4>IXT)TXG"B=`)Y
MXFF7%0``DX7%^1<5```3!<7M(6%O\"_NIH47%0``$P7%]N_P+[:JA6G1%Q4`
M`!,%Q>WO\$_L5;_OT/^P>7$B\";L`!@&])=T``"#M`2WDP5$_1<5```3!47K
MG&`C//3\@4?O\"^R!<6#1P4``46)QY.'!_TS-?```S>$_9Q@N8\!1X'KHG`"
M=.)D16&"@`%%Y;?OT%^K'7$BZ`;L`!`7<P```S,#MBJ.`S4#`!,#A``,Y!#H
M%.QRAACP%WX```,^SJ\<]",X!`,C/!0#FH:)18,W#@`C-/3^@4<C,&3^[]"/
M_A,%\`_OT`_Z'7&BZ$[\4OA6](;LIN3*X%KP7NR`$,%REWH``(.Z2JL6D0E&
M@[<*`",T]/J!1X%%*HKOT+^*DPGU_Q/7^4-!D[.'Z0#"%\&3F8^SB?E`8\P)
M",%WDX<'^C,)]`!]6YU+`4;.A5*%[]!_AV,-90E!9B$&RH52A>_0?Y,!)6,'
M90=C_ZL$816S!*D`8_8D`8&H_11CYB0%(4:7=0``DX7%JB:%[]"_@&WUP7>3
MAP?ZHI<SA?1`3I4#-X3Z@[<*`+F/`4>Q[\%B%I'F8$9DIF0&:>)Y0GJB>@)[
MXFLE88*`P7>^F>.?^?9]5?FW`S>$^H.W"@"YCP%'A><7%0``$P5%W>_PW^H#
M-X3Z@[<*`+F/`4>9YQ<5```3!:7:[_`_Z>_0_Y-!$0;D(N``"._0+^'OT/^+
M$<$(8:)@`F1!`8*`.7$B^$KP3NR```;\EWD``(.Y*9@JB9,%1/P7%0``$P5%
MV(.W"0`C-/3\@4?O\`^3&<4F](-'!0"JA(WGHG0#-X3\@[<)`+F/`4?*A1<5
M```3!275K>M"=.)P`GGB:2%A;_#OQDJ%4NCOT&_:*HHFA>_0[]DJF@D*4H7O
MT$_:)HA*AY<7``"3AT>_4H:7%@``DX:FOXE%JH3OT'^"`S>$_(.W"0"YCP%'
MG>-"=$)JXG`">>)IIH6B=!<5```3!67.(6%O\,_`)O12Z._07X7OT!^%27&7
M=P``DX<GDZ+RRNJ`&L[FTN*&]J;N`[B'`P._!P&#OH<!`[X'`@.SAP*#N`<#
M$PG$ZA=Z```#.HJ(JHD7%@``$P9FRI<6``"3AF:S%Q<``!,'Y\F7%P``DX?G
MR2,X!/'*A1<5```3!06R`S@*`",\!/D!2",P!.XC-`3L(S3D[R,XU.\C/,3O
M(S!D\",T%/$C.,3L(SS4[",\Y.HC,/3L[^"?_A'%@T<%`*J$8YT'(E;^6OI>
M]F+R[]`OQ^_0[_%C"P48`SL%`&,'"QA:A>_0S\:3%!4`A00FA>_0#\<#1PL`
MJHLFC*J*!<^7%@``DX:&P2:&B45>A>_0+^\%"^*&8W.<`*:&LX>60(D'8_/7
M`+:'`T<+`/D4E8R^E(D+<?<3"X3N%Q4``!,%9;0IH`,UBP`A"PW!RH7OX!_U
MJH1EV8-'!0#MU^_@__YUT2:%[]#/W:J$%>$3"P3M@S0+`(G,@\<$`&.'!PXF
MA>_@O_QQZ8,TBP`A"^WT)H7OT`^\*HM6A>_0C[L["ZL`&PM+0%J%[]"ONY<7
M``"3AV>AUH@FAUJ&%Q@``!,(B+:7%@``DX:&MHE%JHOOT$_C7H63!0`<[]"O
MU/U78QCU`._0#[H<045'8YKG#FKJ$PV$\>J%7H7OT*_8JH0!Z8,GA/*]9A%G
M]8]CB><*EV<``(.WQW"#M@D`B&->AQ<6```3!L:UB47OT*_;4FV!2@,WA/F#
M-PH`N8\!1V.3!S"V<!9T4GNR>Q)\]F16:;9I%FI6A?)Z=6&"@":%[]!OSJJ$
M(0OC!P7P);>!1!6WDP2$ZXA@&<G*A>_@G^(!Q8-'!0"5XXADH01]]35%[]!O
MK35,JHNJBN*$%QL``!,+JZ43!S`%N;WOT,_)*HNA!''1[]`OJI,4%0"%!!V]
M@RH$\^_0+ZCCE:KT@R>$\F;N$P<`')/W]Q]CB.<$\FP-OQ=G```#-\=C@[8)
M``AC%Q8``!,&YJ1>AXE%[]"OS@V_[_!_Q`,WA/F#-PH`N8\!1V.>!R(6=+9P
M5FFV:19J)H7V9'5A;]`/PEJ%[]"OH\J%JHH7%0``$P4EJN_@G]:JA6,,!1`#
MM0D`[_#ON:J,8P4%$&:%[]`/H!L,!0"-1V/8AP,3!<S_9I67%0``DX5%I^_0
M3[()[9%'8P/\&)L'O/_FEP/'!P"3!_`"8PKW%LJ%%Q4``!,%18GOX+_0:<&#
M1P4`U<\3!P`#8XOG"I<5``"3A061%Q4``!,%!8?O\(^%[]!/K"J(7H=:AE:%
MEQ@``).(B+"7!P``DX<'?Y<6``"3A@:CB47OT._!?5G%21<<```3#&RN%:CO
MT,^8'$%CG3<#[]`OJ(4D*HABX*:(7H=:AE:%EP<``).'!WN7%@``DX8&H(E%
M[]#OO9,%`!Q6A>_03Z_C`B7]7H7OT*^LUH47!0``$P7%=>_@W_Q6A>_PGZ_R
M;%)M\;N#O`D`W;UFA8%%[]`OP2J),='O\/^9JHGC3@7RDP5E_P%&2H7OT(^F
M$PP$Z^*%2H491N_0K[*91V,=]0@#)P3KMT=!0Y.'!S#C%O?P`U=,`)%GDX>'
M5.,?]^Z3A>G\`49*A>_0KZ)*A>J%$P:``N_0[ZZ3!X`"8Q[U!&J(6H:7&```
MDXCHGY<'``"3AV=N7H>7%@``DX9&D8E%5H4C``3T[]#/L#6_@[F)`..&">A.
MA>_0SX2-1^/PI^AQ%4Z5EQ4``).%Y8SOT&^7XQ8%YLZ,G;4#-X3Y@S<*`+F/
M`4>)ZQ<5```3!46+[_!?AV;N:NKOT,^Q5OY:^E[V8O)F[FKJ[]#/L%UQ)OR7
M9```@[1$.J+@3O12\(;D2OA6[(`(LX=$``.Y!P`3"D3[EVD``(.Y*36#1PD+
MTH47!0``$P5%9P.W"0`C/.3Z`4>C"/D*[^#?KQG%`T<%`),'$`-C`/<6[_#/
MO[.'1``#N0<`2H6-1@5&EQ4``).%I8;OP#__*HD%Q1QI,X=$``ACC&,7%@``
M$P:&A>_`G_Z#-PD!C&/<11.7EP)C2`<2LX=$`(ACC48%1I<5``"3A:6#[\`_
M^RJ)EVH``).*2C@=P=*%%P4``!,%A5COX'^G@S<)`2J&C&-C`P4.LX=$`(AC
M[\`_^;.'1``#N0<`!4:7!0``DX7%?TJ%[\"_[*J%%Q8``!,&1H!*A>_`O_:2
ME)Q@TH47!0``$P6%4J.(!PKOX#^B([BJ`*J$)<&3!0`<)H7OT"^)&P<5`(5'
M8_?G`L5'8P3U`@,WA/N#MPD`N8\!1]GC@[>*`*J&)H:,8Q<%```3!65][]#O
MC`,WA/N#MPD`N8\!1ZWCIF`&9.)T0GFB>0)ZXFIA88*``[6*`._POY(CN*H`
MJH11^0,WA/N#MPD`N8\!1XWK%P4``!,%17;OT$^(@T<5`..&!^IQO8.WB@`N
MA8QC[^#_P3&_LX=$`(AC[]`O@^FU[]#/DCEQ(O@F]$KP@``&_)=D``"#M,08
M*HF3!43\%P4``!,%Y4R<8",T]/R!1^_@WY,)S8-'!0"1RQ,'``-CA^<`8P4)
M`(-'"0")[P,WA/R<8+F/`4>Y[^)P0G2B=`)Y(6&"@$J%3NSO\"^2DP7P`JJ)
M[\"__!G!DPD5`$Z%[\#_^!%&EP4``).%A5;OP!_5&<'B:66_`S>$_)Q@N8\!
M1YGK0G3B:>)PHG1*A0)Y(6%OX#^=3NSOT&^'01$BX`;D``@3!0`([\!_UA=(
M```#.*A'MW9=3#=WZ6&&!K<E16<W5C(0!@>3AN;/DX45,!,&9D<3!P<?%.DC
M-`4"(S@%`B,L!08,X2,T!0$0[1CQHF`"9$$!@H!=<:+@2OA.]%;L6NB&Y";\
M4O"`"!AUDQ<V`+*)NI<0>8(7@9,SM^<`*HF3UMD!*%TZEC.'Q@`C-/D"(SCI
M`BZ+DPJ)`S7MDP?P`V/:-P4;VFD`7N2;"_K_8N`:"A.<"P(37`P"6IK:A*:%
M$P8`!%:%[\!_VY.$!`1*A>_0KZ7CE43_NPMP09N;:P`:#)N)"?P3"PL$NXD[
M`6*;HFL";-J%5H5.AN_`/]@C+#D'IF`&9.)T0GFB>0)ZXFI":V%A@H"3!P`$
MB9^^A&/+^0(;B@0`DPJ)`U*&5I7:A>_`W]2#)XD'$P<`!*6?(RSY!N.0Y_Q*
MA;N)F4!2F^_0SYVIM\Z$\;==<:+@)OQ*^%+P5NQ>Y(;D3O1:Z(`(@[F%`H/6
MA0(#UP4#D]<Y`).+A0.3]_<#$]J&`)-:AP";EH8`&Q>'`#.&^P"NA#-JV@"3
M!0#XL^KJ``.[!`.%)R,`M@!"&L(:$P:``RJ)$UH*`S.%^P"3V@H#8U;V$!,'
M``2[!_=`$4=C\.<2"4=C].<08Y\'#B:%[]!/E%Z%$P:``X%%[\"_W9/7B0$3
M5XL!D]D)`1-;"P$CF50'(YM$!Z.(9`<CBO0&HXHT!R:%(XCD!N_0KY"<8":%
MX8,C`/D`G&#!@Z,`^0"<8*&#(P'Y`)Q@HP'Y`)QDX8,C`OD`G&3!@Z,"^0"<
M9*&#(P/Y`)QDHP/Y`)QHX8,C!/D`G&C!@Z,$^0"<:*&#(P7Y`)QHHP7Y`)QL
MX8,C!OD`G&S!@Z,&^0"<;*&#(P?Y`)QLHP?Y`)QPX8,C"/D`G'#!@Z,(^0"<
M<*&#(PGY`)QPHPGY``9DIF#B=$)YHGD">N)J0FNB:V%A;\#?PQV>@47OP%_/
M*;\C``4`";<C``4`HP`%`/D7.I7CB@?N[;<C``4`HP`%`",!!0"C`04`\1<Z
ME0E'X^KG[-&_01$BX`;D``@"9*)@EV8``(.VYN)!`6_`7Z\!``(``````"5S
M+R5S````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R``````!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R]S96QF+V5X90``97AE```````O<')O
M8R\E:2\E<P``````+@````````!005)?5$5-4```````````4$%27U!23T=.
M04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"````````
M``!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)5
M1P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````
M````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q````````
M`&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%265]0
M051(`%-94U1%30``+W1M<`````!54T52`````%5315).04U%```````````E
M,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9````````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P``````````&`````````!P97)L`````#``````````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64`
M```````M+0```````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`5$U01$E2``!4
M14U01$E2`%1%35``````5$U0``````")J\WO`````'!E<FQX<VDN8P``````
M````0T%#2$4```$;`SOL````'````.B+__^`!P``E(W__P0!``"&CO__+`$`
M``:D__]H`0``LJ3__]@!```>I?__$`(``$BF__]\`@``J*;__Z@"``!XI___
M[`(``$JI__]@`P``@*G__X@#```ZJO__S`,``$JJ___T`P``_JO__T@$```F
MK/__=`0``!BM___`!```OK#___P$```8L?__+`4``&RQ__],!0``CK+__Y0%
M``"JLO__O`4``'RS__\D!@``P+C__^`&``"@NO__)`<``%:[___`!P``LKO_
M_^@'``"TO/__.`@``&Z^__^`"````````!```````````WI2``%\`0$;#0(`
M$````!@```"(C/__(@`````'`0`0``````````-Z4@`!?`$!&PP"`#@````8
M````4HW__X`5````1`[`!42(!$(,"`!>@0*)!I((DPH#/A4*P43(#`+`!43)
M1-)$TT0.`$(+`&P```!4````EJ+__ZP`````0@Y02(@$@0*)!I<20@P(`%J3
M"I0,E0YFD@B6$&C20M-"U$+50M9"P4+(#`)00M=$R4(.`$(-"($"B`2)!I((
MDPJ4#)4.EA"7$E+2UD33U-5$DPJ4#)4.0M-"U$+5```T````Q````-*B__]L
M`````$(.L`%&B`2)!I((0@P(`$J!`@)*"L%"R`P"L`%"R4+20@X`0@L``&@`
M``#\````!J/__RH!````0@[0`4:(!),*@0)"#`@`6HD&1LE2P4+(#`+0`4+3
M0@X`0@T(@0*(!(D&DPI"D@A,E`P"0I4.`ES55`K)0M)"U$(+1I4.2,G2U-5(
MB0:2")0,E0Y$U-5"R4+2`"@```!H`0``Q*/__V``````0@X@0HD&3(@$@0)"
M#`@`9L@,`B!$P4+)7@X`0````)0!``#XH___T`````!"#E!,B`2)!I((DPJ4
M#)4.0@P(`%:!`@)B"@P"4$+!0LA"R4+20M-"U$+50@X`0@L```!P````V`$`
M`(2D___2`0```$(.<%*(!(D&D@B3"H$"E`R5#I<2F!1"#`@``MX*P4+(#`)P
M0LE"TD+30M1"U4+70MA"#@!""W"6$)D6FA@"7@K60ME"VD8+5M;9VD26$)D6
MFAA&UMG:1I80F1::&$;60ME"VB0```!,`@``XJ7__S8`````2@X01(@$@0)"
M#`@`1,@,`A!"P5P.``!`````=`(``/"E__^Z`````$(.8$:!`H@$B09"#`@`
M2I((DPJ4#)4.`HX*#`)@0L%$R$+)0M)"TT+40M5"#@!""P```"0```"X`@``
M9J;__Q``````0@X01(@$@0)"#`@`0L@,`A!"P4(.``!0````X`(``$ZF__^T
M`0```$(.\`%*B`2)!I((DPJ7$D(,"`!@@0*4#)4.EA"8%)D6`DX*#`+P`4+!
M0LA"R4+20M-"U$+50M9"UT+80ME"#@!""P`H````-`,``*ZG__\H`````$(.
M($:(!(D&@0)"#`@`4L@,`B!"P43)0@X``$@```!@`P``JJ?___(`````0@Y`
M2H@$DPJ!`HD&D@A"#`@``IX*#`)`0L%"R$+)0M)"TT(.`$(+4@H,`D!"P4+(
M0LE"TD+32@X`1`LX````K`,``%"H__^F`P```$(.0$B(!(D&D@B3"D(,"`!*
M@0(#3@,*R`P"0$+!0LE"TD+34@X`1`L````L````Z`,``+JK__]:`````$(.
M,$2(!(D&0@P(`$J!`G@*P4+(#`(P0LE"#@!""P`<````&`0``.2K__]4````
M`$(.8$2(%($20@P(0````$0````X!```&*S__R(!````0@Y@4H@$DPJ4#)4.
M@0*)!I((EA"7$D(,"``"L@H,`F!"P4+(0LE"TD+30M1"U4+60M="#@!""R0`
M``"`!```\JS__QP`````0@X01($"B`1"#`@`3L%"R`P"$$(.``!D````J`0`
M`.:L___2`````$(.0$:(!)((DPI"#`@`8H$"3(D&1LE:R`P"0$+!0M)"TT(.
M`$0-"($"B`2)!I((DPI$E`P"1,@,`D!"U$+!0M)"TT3)2@X`1`T(@0*(!)((
MDPI$B0:4#+@````0!0``4*W__T0%````0@[P`DR(!)((0@P(`&23"I0,@0*)
M!@*&E0Z6$)<2F!0#(`&:&`(^VE0*P4+(#`+P`D+60M="V$+)0M)"TT+41-5"
M#@!""P)BFAA:F19&V4+:8-76U]A6R`P"\`)"P4+20M-"U$3)0@X`1`T(@0*(
M!(D&D@B3"I0,E0Z6$)<2F!29%IH8`RP!"ME"VD(+`^P`V=I$F1::&$35UM?8
MV=I,E0Z6$)<2F!29%IH80````,P%``#8L?__X`$```!"#E!"B094B`23"I0,
M@0*2")4.0@P(``-D`0K!0L@,`E!"R4+20M-"U$+50@X`0@L```!8````$`8`
M`'2S__^V`````$(.0$:(!(D&D@A"#`@`8($";`K!0L@,`D!"R4+20@X`0@M$
MDPIL"M-""T[(#`)`0M-"P4+)1-)"#@!$#0B!`H@$B0:2"$*3"@```#P```!L
M!@``8(3__ZP!````0@Y@1H$"B`22"$(,"`!&B0:3"I0,`RP!"L%"R`P"8$+)
M0M)"U$330@X`0@L````D````K`8``(ZS__]<`````$(.$$2(!($"0@P(``).
MP4+(#`(00@X`3````-0&``#"L___`@$```!"#E!0B`22"),*E0Z6$($"B0:4
M#$(,"``"0)<21I@4`D+70MA0"L%"R`P"4$+)0M)"TT+40M5"UD(.`$(+``!$
M````)`<``'2T__^Z`0```$(.4%*(!(D&D@B4#)4.EQ*!`I,*EA!"#`@``U`!
M"L@,`E!"P4+)0M)"TT+40M5"UD+70@X`1`LD````E`<``.:U__\:`````$(.
M$$2(!($"0@P(`$+(#`(00L%*#@``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`0````````#Y`@````````$`````````!`,````````!``````````X#````
M````'0````````"X!````````"``````````>*L````````A``````````@`
M````````&0````````"`JP```````!L`````````"``````````:````````
M`(BK````````'``````````(`````````/7^_V\`````V`(````````%````
M`````.@-````````!@````````!P!`````````H`````````VP0````````+
M`````````!@`````````%0````````````````````,`````````L*T`````
M```"`````````%@%````````%``````````'`````````!<`````````,!8`
M```````'`````````/`3````````"`````````"8!P````````D`````````
M&``````````>``````````@`````````^___;P`````!```(`````/[__V\`
M````D!,```````#___]O``````(`````````\/__;P````#$$@```````/G_
M_V\`````#0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/__________``````````"0&P```````)`;````````D!L```````"0
M&P```````)`;````````D!L```````"0&P```````)`;````````D!L`````
M``"0&P```````)`;````````D!L```````"0&P```````)`;````````D!L`
M``````"0&P```````)`;````````D!L```````"0&P```````)`;````````
MD!L```````"0&P```````)`;````````D!L```````"0&P```````)`;````
M````D!L```````"0&P```````)`;````````D!L```````"0&P```````)`;
M````````D!L```````"0&P```````)`;````````D!L```````"0&P``````
M`)`;````````D!L```````"0&P```````)`;````````D!L```````"0&P``
M`````)`;````````D!L```````"0&P```````)`;````````D!L```````"0
M&P```````)`;````````D!L```````"0&P```````)`;````````D!L`````
M``"0&P```````)`;````````D!L```````"0JP``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````I005(N<&T*````````````````````````
M````````````````````````````````````````````````````````````
M`$=#0SH@*$=.52D@,30N,BXQ(#(P,C0P.#`U`$%E````<FES8W8``5L````$
M$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R<#!?>FEC<W(R<#!?
M>FEF96YC96DR<#!?>FUM=6PQ<#!?>F%A;6\Q<#!?>F%L<G-C,7`P```N<VAS
M=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A
M9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU
M+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+G!R96EN:71?87)R87D`+FEN:71?
M87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC
M;VUM96YT`"YR:7-C=BYA='1R:6)U=&5S````````````````````````````
M```````````````````````````````````````````````````````````+
M`````0````(`````````<`(```````!P`@```````"$`````````````````
M```!````````````````````$P````<````"`````````)0"````````E`(`
M```````D````````````````````!````````````````````"8````'````
M`@````````"X`@```````+@"````````(`````````````````````0`````
M```````````````T````]O__;P(`````````V`(```````#8`@```````)0!
M````````!0`````````(````````````````````/@````L````"````````
M`'`$````````<`0```````!X"0````````8````"````"``````````8````
M`````$8````#`````@````````#H#0```````.@-````````VP0`````````
M``````````$```````````````````!.````____;P(`````````Q!(`````
M``#$$@```````,H`````````!0`````````"``````````(`````````6P``
M`/[__V\"`````````)`3````````D!,```````!@``````````8````"````
M"````````````````````&H````$`````@````````#P$P```````/`3````
M````0`(````````%``````````@`````````&`````````!T````!````$(`
M````````,!8````````P%@```````%@%````````!0```!0````(````````
M`!@`````````>0````$````&`````````)`;````````D!L```````"P`P``
M````````````````$``````````0`````````'X````!````!@````````!`
M'P```````$`?````````H#(```````````````````0`````````````````
M``"$`````0````(`````````X%$```````#@40```````'=!````````````
M```````(````````````````````C`````$````"`````````%B3````````
M6),```````#L````````````````````!````````````````````)H````!
M`````@````````!(E````````$B4````````O`<```````````````````@`
M``````````````````"D````$`````,`````````>*L```````!XJP``````
M``@````````````````````!``````````@`````````LP````X````#````
M`````("K````````@*L````````(````````````````````"``````````(
M`````````+\````/`````P````````"(JP```````(BK````````"```````
M``````````````@`````````"`````````#+````!@````,`````````D*L`
M``````"0JP```````"`"````````!@`````````(`````````!``````````
MU`````$````#`````````+"M````````L*T```````!0`@``````````````
M````"``````````(`````````-D````!`````P``````````L`````````"P
M````````4`````````````````````@```````````````````#?````"```
M``,`````````4+````````!0L````````"@````````````````````(````
M````````````````Y`````$````P````````````````````4+`````````;
M`````````````````````0`````````!`````````.T````#``!P````````
M`````````````&NP````````9@````````````````````$`````````````
M```````!`````P````````````````````````#1L````````/\`````````
8```````````!````````````````````
